@@ -9,20 +9,26 @@ function(x, data=mydata, n.cat=getOption("n.cat"), type=NULL,
 
          col.area=NULL, col.box="black",
 
-         shape.pts=21, cex.axis=0.85, col.axis="gray30",
+         shape.pts=21, cex.axis=0.75, col.axis="gray30",
+
+         rotate.values=0, offset=.5,
+
          xy.ticks=TRUE, line.width=1.1,
-         xlab=NULL, ylab=NULL, main=NULL, cex=NULL,
+         xlab=NULL, ylab=NULL, main=NULL, sub=NULL, cex=NULL,
 
          time.start=NULL, time.by=NULL, time.reverse=FALSE,
 
          center.line=c("default", "mean", "median", "zero", "off"),
 
-         quiet=getOption("quiet"),
+         show.runs=FALSE, quiet=getOption("quiet"),
          pdf.file=NULL, pdf.width=5, pdf.height=5, ...) {
 
 
   center.line <- match.arg(center.line)
 
+  if (!is.null(pdf.file))
+    if (!grepl(".pdf", pdf.file)) pdf.file <- paste(pdf.file, ".pdf", sep="")
+
   # get actual variable name before potential call of data$x
   x.name <- deparse(substitute(x))
   options(xname = x.name)
@@ -34,6 +40,9 @@ function(x, data=mydata, n.cat=getOption("n.cat"), type=NULL,
   pdf.nm <- FALSE
   if (!missing(pdf.file)) pdf.nm <- TRUE
 
+  if (!quiet && !show.runs)
+    cat("[To view the individual runs: show.runs=TRUE]\n")
+
 # -----------------------------------------------------------
 # establish if a data frame, if not then identify variable(s)
 
@@ -89,10 +98,10 @@ function(x, data=mydata, n.cat=getOption("n.cat"), type=NULL,
 
       .lc.main(data[,i], type,
          col.line, col.area, col.box, col.stroke, col.fill, shape.pts,
-         col.grid, col.bg, cex.axis, col.axis, xy.ticks,
-         line.width, xlab, ylab, main, cex,
+         col.grid, col.bg, cex.axis, col.axis, rotate.values, offset, xy.ticks,
+         line.width, xlab, ylab, main, sub, cex,
          time.start, time.by, time.reverse, 
-         center.line, quiet, ...)
+         center.line, show.runs, quiet, ...)
 
       if (go.pdf) {
         dev.off()
